@@ -6,7 +6,7 @@ use Nephia::ClassLoader;
 
 sub new {
     my ( $class, %opts ) = @_;
-    $opts{class} ||= 'Xslate';
+    $opts{class} ||= 'MicroTemplate';
     my $subclass = join '::', __PACKAGE__, delete $opts{class};
     Nephia::ClassLoader->load( $subclass );
     return $subclass->new( %opts );
